// Sample script based action types for Trespasser CE
// These are script versions of some original ActionTypes for demonstration purposes.
//
// Disclaimer: They haven't been tested and may contain bugs.

// ActionType 0 - Voiceover action
class AT00 extends ActionType
{
	sndhSample = null;
	parent = null;
	i4_spatial = null;
	f_volume = null;
	f_atten = null;
	f_out_vol = null;
	f_frustum = null;

	function OnScriptInit(triggerOwner)
	{
		parent = triggerOwner;

		sndhSample = TP_Engine.sound_uid( GetPropString(esTActionSample) );
		if (sndhSample == null)
		{
			print("AT00 init failed, missing 'Sample' property");
			sndhSample = TP_Engine.sound_uid("MISSING");
		}

		i4_spatial = GetPropInt(esTActionSpatial, AU_STEREO);
		f_volume = GetPropFloat(esTActionVolume, 0.0);
		f_atten = GetPropFloat(esTActionAtten, 1.0);
		f_out_vol = GetPropFloat(esTActionOutsideVol, -15.0);
		f_frustum = GetPropFloat(esTActionFrustum, 360.0);

		// name of the emmiter object, if there is one
		local emitter = TP_Engine.FindUnmappedInstance( GetPropString(esTActionEmitter) );
		if (emitter)
			parent = emitter;
	}

	function Run()
	{
		// don't play VO if player is dead
		if ( TP_Engine.GetPlayer().bDead() )
			return;

		TP_Engine.PlaySound(sndhSample, eamVOICEOVER, parent, f_volume, f_atten, i4_spatial, f_frustum, f_out_vol, false, 0, 100000.0, 0.0, 0.0);
	}
}

// ActionType 16 - Load a new level
class AT16 extends ActionType
{
	strLevelName = null;

	function OnScriptInit(triggerOwner)
	{
		strLevelName = GetPropString(esLevelName);
	}

	function Run()
	{
		if (strLevelName != null)
			TP_Engine.SetNextLevel(strLevelName);
	}
}

// ActionType 15 - Water entity update enable/disable
class AT15 extends ActionType
{
	u4WaterEntity = null;
	bEnable = null;

	function OnScriptInit(triggerOwner)
	{
		u4WaterEntity = TP_Engine.uid( GetPropString(esObjectName) );
		bEnable = GetPropBool(esEnable, false);
	}

	function Run()
	{
		water = TP_Engine.FindUnmappedInstance(u4WaterEntity);

		if (water instanceof CEntityWater)
			water.Enable(bEnable);
	}
}

// ActionType 11 - Substitute mesh
class AT11 extends ActionType
{
	target = null;
	iSubstitute = null;

	function OnScriptInit(triggerOwner)
	{
		target = TP_Engine.FindUnmappedInstance( GetPropString(esTarget) );
		iSubstitute = GetPropInt(esSubstitute);
	}

	function Run()
	{
		if (target instanceof CAnimate && iSubstitute != null)
			target.Substitute(iSubstitute);
	}
}

// ActionType 25 - Delay
class AT25 extends ActionType
{
	fDelay = null;

	function OnScriptInit(triggerOwner)
	{
		fDelay = GetPropFloat(esDelay, 0.0);
	}

	function GetDuration()
	{
		return fDelay;
	}
}
